@@ -4,7 +4,7 @@
 #
 package  Test::Tech;
 
-use 5.001;
+# use 5.001;
 use strict;
 use warnings;
 use warnings::register;
@@ -13,14 +13,14 @@ use Test ();   # do not import the "Test" subroutines
 use Data::Secs2 qw(stringify);
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.17';
-$DATE = '2004/04/10';
+$VERSION = '1.21';
+$DATE = '2004/04/26';
 $FILE = __FILE__;
 
 use vars qw(@ISA @EXPORT_OK);
 require Exporter;
 @ISA=('Exporter');
-@EXPORT_OK = qw(tech_config plan ok skip skip_tests stringify demo finish);
+@EXPORT_OK = qw(demo finish is_skip ok plan skip skip_tests stringify tech_config);
 
 #######
 # For subroutine interface keep all data hidden in a local hash of private object
@@ -82,309 +82,6 @@ sub new
 
 }
  
-
-#####
-# Restore the Test:: moduel variable back to where they were when found
-#
-sub finish
-{
-    my $self = UNIVERSAL::isa($_[0],__PACKAGE__) ? shift @_ : $tech_p;
-
-    $Test::TESTOUT = $self->{TestDefault}->{TESTOUT};
-    $Test::TestLevel = $self->{TestDefault}->{TestLevel};
-    $Test::ONFAIL = $self->{TestDefault}->{ONFAIL};
-    $Test::TESTERR = $self->{TestDefault}->{TESTERR} if defined $Test::TESTERR;
-
-    return unless $Test::TESTOUT;  # if IO::Handle object may be destroyed and undef
-    return unless $self->{last_test} && $self->{num_tests};  
-
-    my $missing = $self->{last_test} + 1;
-    while($missing <= $self->{num_tests}) {
-         push @{$self->{missed}}, $missing++;
-    }
-    if(@{$self->{unplanned}}) {
-        print $Test::TESTOUT '# Extra  : ' . (join ' ', @{$self->{unplanned}}) . "\n";
-    }
-    if(@{$self->{missed}}) {
-        print $Test::TESTOUT '# Missing: ' . (join ' ', @{$self->{missed}}) . "\n";
-    }
-    if(@{$self->{skipped}}) {
-        print $Test::TESTOUT '# Skipped: ' . (join ' ', @{$self->{skipped}}) . "\n";
-    }
-    if(@{$self->{failed}}) {
-        print $Test::TESTOUT '# Failed : ' . (join ' ', @{$self->{failed}}) . "\n";
-    }
-    use integer;
-
-    my $total = $self->{num_tests} if $self->{num_tests};
-    $total = $self->{last_test} if $self->{last_test} && $self->{num_tests} < $self->{last_test};
-    $total -= @{$self->{skipped}};
-
-    my $passed =  @{$self->{passed}};
-    print $Test::TESTOUT '# Passed : ' . "$passed/$total " . ((100*$passed)/$total) . "%\n" if $total;
-
-    return ($total,$self->{unplanned},$self->{missed},$self->{skipped},$self->{passed},$self->{failed})
-          if wantarray;
-
-    $passed;
-}
-
-# *finish = &*Test::Tech::DESTORY; # DESTORY is alias for finish
-sub DESTORY 
-{
-    finish( @_ );
-
-}
-
-
-
-######
-# Cover function for &Test::plan that sets the proper 'Test::TestLevel'
-# and outputs some info on the current site
-#
-sub plan
-{
-   ######
-   # This subroutine uses no object data; therefore,
-   # drop any class or object.
-   #
-   shift @_ if UNIVERSAL::isa($_[0],__PACKAGE__);
-
-   &Test::plan( @_ );
-
-   ###############
-   #  
-   # Establish default for Test
-   #
-   # Test 1.24 resets global variables in plan which
-   # never happens in 1.15
-   #
-   $Test::TestLevel = 1;
-
-   my $loctime = localtime();
-   my $gmtime = gmtime();
-
-   my $perl = "$]";
-   if(defined(&Win32::BuildNumber) and defined &Win32::BuildNumber()) {
-       $perl .= " Win32 Build " . &Win32::BuildNumber();
-   }
-   elsif(defined $MacPerl::Version) {
-       $perl .= " MacPerl version " . $MacPerl::Version;
-   }
-
-   print $Test::TESTOUT <<"EOF" unless 1.20 < $Test::VERSION ;
-# OS            : $^O
-# Perl          : $perl
-# Local Time    : $loctime
-# GMT Time      : $gmtime
-# Test          : $Test::VERSION
-EOF
-
-   print $Test::TESTOUT <<"EOF";
-# Test::Tech    : $VERSION
-# Data::Secs2   : $Data::Secs2::VERSION
-# =cut 
-EOF
-
-   1
-}
-
-
-######
-# Cover function for &Test::ok that adds capability to test 
-# complex data structures.
-#
-sub ok
-{
-
-   ######
-   # If no object, use the default $tech_p object.
-   #
-   my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
-
-   my ($diagnostic,$name) = ('',''); 
-   my $options = {};
-   if( ref($_[-1]) ) {
-       $options = pop @_;
-       if( ref($options) eq 'ARRAY') {
-           my %options = @$options;
-           $options = \%options;
-       }
-       elsif( ref($options) ne 'HASH') {
-           $options = {};
-       }
-   }
-   $diagnostic = $options->{diagnostic} if defined $options->{diagnostic};
-   $name = $options->{name} if defined $options->{name};
-
-   my ($actual_result, $expected_result, $diagnostic_in, $name_in) = @_;
-
-
-   ######### 
-   # Fill in undefined inputs
-   #
-   $diagnostic = $diagnostic_in if defined $diagnostic_in;
-   $name = $name_in if defined $name_in;
-   $diagnostic = $name unless defined $diagnostic;
-   $self->{test_name} = $name;  # used by tied handle Test::Tech::Output
-
-   if($self->{Skip_Tests}) { # skip rest of tests switch
-       &Test::skip( 1, 0, '');
-       if($self->{Skip_Diag}) {
-           my $test_number = $Test::ntest - 1;
-           print $Test::TESTOUT "# Test $test_number got:\n";
-           print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
-       }
-       return 1; 
-   }
-
-   &Test::ok(stringify($actual_result), stringify($expected_result), $diagnostic);
-
-}
-
-
-######
-#
-#
-sub skip
-{
-
-   ######
-   # If no object, use the default $tech_p object.
-   #
-   my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
-
-   my ($diagnostic,$name) = ('',''); 
-   my $options = {};
-   if( ref($_[-1]) ) {
-       $options = pop @_;
-       if( ref($options) eq 'ARRAY') {
-           my %options = @$options;
-           $options = \%options;
-       }
-       elsif( ref($options) ne 'HASH') {
-           $options = {};
-       }
-   }
-   $diagnostic = $options->{diagnostic} if $options->{diagnostic};
-   $name = $options->{name} if $options->{name};
-
-   my ($mod, $actual_result, $expected_result, $diagnostic_in, $name_in) = @_;
-
-   $diagnostic = $diagnostic_in if defined $diagnostic_in;
-   $name = $name_in if defined $name_in;
-   $diagnostic = $name unless defined $diagnostic;
-   $self->{test_name} = $name;  # used by tied handle Test::Tech::Output
-
-   if($self->{Skip_Tests}) {  # skip rest of tests switch
-       &Test::skip( 1, 0, '');
-       if($self->{Skip_Diag}) {
-           my $test_number = $Test::ntest - 1;
-           print $Test::TESTOUT "# Test $test_number got:\n";
-           print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
-       }
-       return 1; 
-   }
-  
-   &Test::skip($mod, stringify($actual_result), stringify($expected_result), $diagnostic);
-
-}
-
-
-######
-#
-#
-sub skip_tests
-{
-
-   ######
-   # If no object, use the default $tech_p object.
-   #
-   my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
-
-   my ($value,$diagnostic) =  @_;
-   my $result = $self->{Skip_Tests};
-   $value = 1 unless (defined $value);
-   $self->{Skip_Tests} = $value;
-   $diagnostic = 'Test not performed because of previous failure.' unless defined $diagnostic;
-   $self->{Skip_Diag} = $value ? $diagnostic : '';
-   $result;   
-}
-
-
-#######
-# This accesses the values in the %tech hash
-#
-# Use a dot notation for following down layers
-# of hashes of hashes
-#
-sub tech_config
-{
-
-   ######
-   # If no object, use the default $tech_p object.
-   #
-   my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
-
-   my ($key, $value) = @_;
-   my @keys = split /\./, $key;
-
-   #########
-   # Follow the hash with the current
-   # dot index until there are no more
-   # hashes. For success, the dot hash 
-   # notation must match the structure.
-   #
-   my $key_p = $self;
-   while (@keys) {
-
-       $key = shift @keys;
-
-       ######
-       # Do not allow creation of new configs
-       #
-       if( defined( $key_p->{$key}) ) {
-
-           ########
-           # Follow the hash
-           # 
-           if( ref($key_p->{$key}) eq 'HASH' ) { 
-               $key_p  = $key_p->{$key};
-           }
-           else {
-              if(@keys) {
-                   warn( "More key levels than hashes.\n");
-                   return undef; 
-              } 
-              last;
-           }
-       }
-   }
-
-
-   #########
-   # References to arrays and scalars in the config may
-   # be transparent.
-   #
-   my $current_value = $key_p->{$key};
-   if( ref($current_value) eq 'SCALAR') {
-       $current_value = $$current_value;
-   }
-   if (defined $value && $key ne 'ntest') {
-       if( ref($value) eq 'SCALAR' ) {
-           ${$key_p->{$key}} = $$value;
-       }
-       else {
-           ${$key_p->{$key}} = $value;
-       }
-   }
-
-   $current_value;
-
-}
-
-
-
 ######
 # Demo
 #
@@ -396,7 +93,7 @@ sub demo
    # This subroutine uses no object data; therefore,
    # drop any class or object.
    #
-   shift @_ if UNIVERSAL::isa($_[0],__PACKAGE__);
+   shift if UNIVERSAL::isa($_[0],__PACKAGE__);
 
    my ($quoted_expression, @expression) = @_;
 
@@ -435,6 +132,366 @@ sub demo
 
 }
 
+#####
+# Restore the Test:: moduel variable back to where they were when found
+#
+sub finish
+{
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = UNIVERSAL::isa($_[0],__PACKAGE__) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+
+    return undef unless $Test::TESTOUT;  # if IO::Handle object may be destroyed and undef
+    return undef unless $Test::planned;  
+
+    my $missing = $self->{last_test} + 1;
+    $self->{test_name} = '';
+    while($missing <= $self->{num_tests}) {
+        print $Test::TESTOUT "not ok $missing Not Performed # missing $self->{Skip_Diag}\n";
+        if( 1.20 < $Test::VERSION ) {
+            print $Test::TESTERR "# Test $missing got: (Missing)\n";
+            print $Test::TESTERR "# Expected: (Missing)\n";
+        }
+        else {
+            print $Test::TESTOUT "# Test $missing got: (Missing)\n";
+            print $Test::TESTOUT "# Expected: (Missing)\n";
+        }
+        push @{$self->{missed}}, $missing++;
+    }
+
+    $Test::TESTOUT = $self->{TestDefault}->{TESTOUT};
+    $Test::TestLevel = $self->{TestDefault}->{TestLevel};
+    $Test::ONFAIL = $self->{TestDefault}->{ONFAIL};
+    $Test::TESTERR = $self->{TestDefault}->{TESTERR} if defined $Test::TESTERR;
+
+    if(@{$self->{unplanned}}) {
+        print $Test::TESTOUT '# Extra  : ' . (join ' ', @{$self->{unplanned}}) . "\n";
+    }
+    if(@{$self->{missed}}) {
+        print $Test::TESTOUT '# Missing: ' . (join ' ', @{$self->{missed}}) . "\n";
+    }
+    if(@{$self->{skipped}}) {
+        print $Test::TESTOUT '# Skipped: ' . (join ' ', @{$self->{skipped}}) . "\n";
+    }
+    if(@{$self->{failed}}) {
+        print $Test::TESTOUT '# Failed : ' . (join ' ', @{$self->{failed}}) . "\n";
+    }
+    use integer;
+
+    my $total = $self->{num_tests} if $self->{num_tests};
+    $total = $self->{last_test} if $self->{last_test} && $self->{num_tests} < $self->{last_test};
+    $total -= @{$self->{skipped}};
+
+    my $passed =  @{$self->{passed}};
+    print $Test::TESTOUT '# Passed : ' . "$passed/$total " . ((100*$passed)/$total) . "%\n" if $total;
+
+    ######
+    # Only once per test run.
+    #
+    $Test::planned = 0;
+
+    return ($total,$self->{unplanned},$self->{missed},$self->{skipped},$self->{passed},$self->{failed})
+          if wantarray;
+
+    $passed ? 1 : 0;
+}
+
+# *finish = &*Test::Tech::DESTORY; # DESTORY is alias for finish
+sub DESTORY 
+{
+    finish( @_ );
+
+}
+
+
+######
+#
+#
+sub is_skip
+{
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+    return ($self->{Skip_Tests}, $self->{Skip_Diag}) if wantarray;
+    $self->{Skip_Tests};
+   
+}
+
+######
+# Cover function for &Test::ok that adds capability to test 
+# complex data structures.
+#
+sub ok
+{
+
+    ######
+    # If no object, use the default $tech_p object.
+    #
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+
+    my ($diagnostic,$name) = ('',''); 
+    my $options = {};
+    if( ref($_[-1]) ) {
+       $options = pop @_;
+       if( ref($options) eq 'ARRAY') {
+           my %options = @$options;
+           $options = \%options;
+       }
+       elsif( ref($options) ne 'HASH') {
+           $options = {};
+       }
+    }
+    $diagnostic = $options->{diagnostic} if defined $options->{diagnostic};
+    $name = $options->{name} if defined $options->{name};
+
+    my ($actual_result, $expected_result, $diagnostic_in, $name_in) = @_;
+
+
+    ######### 
+    # Fill in undefined inputs
+    #
+    $diagnostic = $diagnostic_in if defined $diagnostic_in;
+    $name = $name_in if defined $name_in;
+    $diagnostic = $name unless defined $diagnostic;
+    $self->{test_name} = $name;  # used by tied handle Test::Tech::Output
+
+    if($self->{Skip_Tests}) { # skip rest of tests switch
+        &Test::skip( 1, '', '', $self->{Skip_Diag});
+        return 1; 
+    }
+
+    $actual_result = stringify($actual_result);
+    $expected_result = stringify($expected_result);
+    foreach ($actual_result,$expected_result) {
+        if(ref($_)) {
+            $$_ =~ s/\n\n/\n# /g; 
+            $$_ =~ s/\n([^#])/\n# $1/g;
+            $diagnostic = 'Test::Tech::stringify() broken.';
+            $self->{test_name} .= ' # ' . $diagnostic;
+            &Test::ok($$_,'',$diagnostic,$diagnostic);
+            return 0;
+        }
+    } 
+
+    &Test::ok($actual_result, $expected_result, $diagnostic);
+
+}
+
+######
+# Cover function for &Test::plan that sets the proper 'Test::TestLevel'
+# and outputs some info on the current site
+#
+sub plan
+{
+   ######
+   # This subroutine uses no object data; therefore,
+   # drop any class or object.
+   #
+   shift if UNIVERSAL::isa($_[0],__PACKAGE__);
+
+   &Test::plan( @_ );
+
+   ###############
+   #  
+   # Establish default for Test
+   #
+   # Test 1.24 resets global variables in plan which
+   # never happens in 1.15
+   #
+   $Test::TestLevel = 1;
+
+   my $loctime = localtime();
+   my $gmtime = gmtime();
+
+   my $perl = "$]";
+   if(defined(&Win32::BuildNumber) and defined &Win32::BuildNumber()) {
+       $perl .= " Win32 Build " . &Win32::BuildNumber();
+   }
+   elsif(defined $MacPerl::Version) {
+       $perl .= " MacPerl version " . $MacPerl::Version;
+   }
+
+   print $Test::TESTOUT <<"EOF" unless 1.20 < $Test::VERSION ;
+# OS            : $^O
+# Perl          : $perl
+# Local Time    : $loctime
+# GMT Time      : $gmtime
+# Test          : $Test::VERSION
+EOF
+
+   print $Test::TESTOUT <<"EOF";
+# Test::Tech    : $VERSION
+# Data::Secs2   : $Data::Secs2::VERSION
+# Data::SecsPack: $Data::SecsPack::VERSION
+# =cut 
+EOF
+
+   1
+}
+
+######
+#
+#
+sub skip
+{
+
+    ######
+    # If no object, use the default $tech_p object.
+    #
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+
+    my ($diagnostic,$name) = ('',''); 
+    my $options = {};
+    if( ref($_[-1]) ) {
+        $options = pop @_;
+        if( ref($options) eq 'ARRAY') {
+            my %options = @$options;
+            $options = \%options;
+        }
+        elsif( ref($options) ne 'HASH') {
+            $options = {};
+        }
+    }
+    $diagnostic = $options->{diagnostic} if $options->{diagnostic};
+    $name = $options->{name} if $options->{name};
+
+    my ($mod, $actual_result, $expected_result, $diagnostic_in, $name_in) = @_;
+
+    $diagnostic = $diagnostic_in if defined $diagnostic_in;
+    $name = $name_in if defined $name_in;
+    $diagnostic = $name unless defined $diagnostic;
+    $self->{test_name} = $name;  # used by tied handle Test::Tech::Output
+
+    if($self->{Skip_Tests}) {  # skip rest of tests switch
+        &Test::skip( 1, '', '', $self->{Skip_Diag});
+        return 1; 
+    }
+  
+    $actual_result = stringify($actual_result);
+    $expected_result = stringify($expected_result);
+    foreach ($actual_result,$expected_result) {
+        if(ref($_)) {
+            $$_ =~ s/\n\n/\n# /g; 
+            $$_ =~ s/\n([^#])/\n# $1/g;
+            $diagnostic = 'Test::Tech::stringify() broken.';
+            $self->{test_name} .= ' # ' . $diagnostic;
+            &Test::ok($$_,'',$diagnostic,$diagnostic);
+            return 0;
+        }
+    } 
+
+    &Test::skip($mod, $actual_result, $expected_result, $diagnostic);
+
+}
+
+
+######
+#
+#
+sub skip_tests
+{
+
+    ######
+    # If no object, use the default $tech_p object.
+    #
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+
+    my ($value,$diagnostic) =  @_;
+    my $result = $self->{Skip_Tests};
+    $value = 1 unless (defined $value);
+    $self->{Skip_Tests} = $value;
+    $diagnostic = 'Test not performed because of previous failure.' unless defined $diagnostic;
+    $self->{Skip_Diag} = $value ? $diagnostic : '';
+    $result;
+   
+}
+
+
+
+
+
+
+#######
+# This accesses the values in the %tech hash
+#
+# Use a dot notation for following down layers
+# of hashes of hashes
+#
+sub tech_config
+{
+
+    ######
+    # If no object, use the default $tech_p object.
+    #
+    $tech_p = Test::Tech->new() unless $tech_p;
+    my $self = (UNIVERSAL::isa($_[0],__PACKAGE__) && ref($_[0])) ? shift @_ : $tech_p;
+    $self = ref($self) ? $self : $tech_p;
+
+    my ($key, $value) = @_;
+    my @keys = split /\./, $key;
+
+    #########
+    # Follow the hash with the current
+    # dot index until there are no more
+    # hashes. For success, the dot hash 
+    # notation must match the structure.
+    #
+    my $key_p = $self;
+    while (@keys) {
+
+        $key = shift @keys;
+
+        ######
+        # Do not allow creation of new configs
+        #
+        if( defined( $key_p->{$key}) ) {
+
+            ########
+            # Follow the hash
+            # 
+            if( ref($key_p->{$key}) eq 'HASH' ) { 
+                $key_p  = $key_p->{$key};
+            }
+            else {
+               if(@keys) {
+                   warn( "More key levels than hashes.\n");
+                   return undef; 
+               } 
+               last;
+            }
+        }
+    }
+
+
+    #########
+    # References to arrays and scalars in the config may
+    # be transparent.
+    #
+    my $current_value = $key_p->{$key};
+    if( ref($current_value) eq 'SCALAR') {
+        $current_value = $$current_value;
+    }
+    if (defined $value && $key ne 'ntest') {
+        if( ref($value) eq 'SCALAR' ) {
+            ${$key_p->{$key}} = $$value;
+        }
+        else {
+            ${$key_p->{$key}} = $value;
+        }
+    }
+
+    $current_value;
+}
+
+
+
+
 
 ########
 # Handle Tie to catch the Test module output
@@ -465,7 +522,9 @@ sub PRINT
     my $buf = join(defined $, ? $, : '',@_);
     $buf .= $\ if defined $\;
     my $test_name = $self->{tech}->{test_name};
+    my $skip_diag = $self->{tech}->{Skip_Diag};
     $buf =~ s/(ok \d+)/$1 - $test_name /g if($test_name);
+    $buf =~ s/(# skip.*?)(\s*|\n)/$1 - $skip_diag$2/ig if $skip_diag;
     $self->stats($buf);
     my $handle = $self->{test_out};
     print $handle $buf;
@@ -528,11 +587,17 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  #
  # (use for &Test::plan, &Test::ok, &Test::skip drop in)
  #  
- use Test::Tech qw(plan ok skip skip_tests tech_config stringify demo);
+ use Test::Tech qw(demo finish is_skip ok plan skip skip_tests stringify tech_config);
 
- $new_value  = tech_config( $key, $old_value);
 
- $success = plan(@args);
+
+ demo($quoted_expression, @expression)
+
+ (@stats) = finish( );
+ $num_passed = finish( );
+
+ $skip_on = is_skip( );
+ ($skip_on, $skip_diag) = is_skip( );
 
  $test_ok = ok($actual_results, $expected_results, [@options]);
  $test_ok = ok($actual_results, $expected_results, {@options});
@@ -541,6 +606,8 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
  $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, {@options});
 
+ $success = plan(@args);
+
  $test_ok = skip($skip_test, $actual_results,  $expected_results, [@options]);
  $test_ok = skip($skip_test, $actual_results,  $expected_results, {@options});
  $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, [@options]);
@@ -548,18 +615,16 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, [@options]);
  $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, {@options});
 
- $state = skip_tests( $on_off, $skip_diagnostic);
- $state = skip_tests( $on_off );
- $state = skip_tests( );
+ $skip_on = skip_tests( $on_off, $skip_diagnostic);
+ $skip_on = skip_tests( $on_off );
+ $skip_on = skip_tests( );
 
  $string = stringify( $var, @options); # imported from Data::Secs2
- $string = $tech->stringify($var, [@options]);
- $string = $tech->stringify($var, {@options});
+ $string = stringify($var, [@options]);
+ $string = stringify($var, {@options});
 
- (@stats) = finish( );
- $num_passed = finish( );
+ $new_value  = tech_config( $key, $old_value);
 
- demo($quoted_expression, @expression)
 
 
  #####
@@ -567,6 +632,14 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  # 
  $tech = new Test::Tech;
 
+ $tech->demo($quoted_expression, @expression)
+
+ (@stats) = $tech->finish( );
+ $num_passed = $tech->finish( );
+
+ $skip_on = $tech->is_skip( );
+ ($skip_on, $skip_diag) = $tech->is_skip( );
+
  $test_ok = $tech->ok($actual_results, $expected_results, [@options]);
  $test_ok = $tech->ok($actual_results, $expected_results, {@options]};
  $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, [@options]);
@@ -583,6 +656,7 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
 
  $state  = $tech->skip_tests( );
  $state  = $tech->skip_tests( $on_off );
+
  $state = skip_tests( $on_off, $skip_diagnostic );
 
  $string = $tech->stringify($var); # imported from Data::Secs2
@@ -592,11 +666,6 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
 
  $new_value = $tech->tech_config($key, $old_value);
 
- (@stats) = $tech->finish( );
- $num_passed = $tech->finish( );
-
- $tech->demo($quoted_expression, @expression)
-
 =head1 DESCRIPTION
 
 The "Test::Tech" module extends the capabilities of the "Test" module.
@@ -647,37 +716,94 @@ session using the methods under test
 
 =back
 
-=head2 plan subroutine
+=head2 demo subroutine
 
- $success = plan(@args);
+ demo($quoted_expression, @expression)
 
-The I<plan> subroutine is a cover method for &Test::plan.
-The I<@args> are passed unchanged to &Test::plan.
-All arguments are options. Valid options are as follows:
+The demo subroutine/method provides a session like out.
+The '$quoted_express' is printed out as typed in from
+the keyboard.
+The '@expression' is executed and printed out as the
+results of '$quoted_expression'.
+
+
+=head2 finish subroutine
+
+ (@stats) = $tech->finish( );
+ $num_passed = $tech->finish( );
+
+The C<finish()> subroutine/method restores changes made
+to the C<Test> module module made by the 
+C<tech_config> subroutine/method or directly.
+
+When the C<new> subroutine/method creates a C<Test::Tech>
+object.
+Perl will automatically run the
+C<finish()> method when that object is destoried.
+
+Running the 'finish' method without a class or object,
+restores the 'Test' module to the values when
+the 'Test::Tech' module was loaded.
+
+When used in an array context
+the C<finish()> subroutine/method 
+returns the C<@stats> array.
+The C<@stats> array consists of the following:
+
+The C<finish()> subroutine resets the C<last_test> and
+to zero and will returns undef without
+performing any of the above. 
+The C<finish()> subroutine will not be active again
+until a new test run is start with  C<&Test::Tech::plan>
+and the first test performed by C<&Test::Tech::ok> or
+C<&Test::Tech::skip>.
+
+In a scalar contents, the C<finish()> subroutine/method outputs
+a 1 for sucess and 0 for failure.
+In an array context,
+the C<finish()> subroutine/method outputs C<@stats>
+array that consists of the following:
 
 =over 4
 
-=item tests
+=item 0
 
-The number of tests. For example
+number of tests
 
- tests => 14,
+This is calculated as the maximum of the tests planned
+and the highest test number. From the maximum, substract
+the skipped tests. In other words, the sum of the missed,
+passed and failed test steps.
 
-=item todo
+=item 1
 
-An array of test that will fail. For example
+reference to the unplanned test steps
 
- todo => [3,4]
+=item 2
 
-=item onfail
+reference to the missed test steps
 
-A subroutine that the I<Test> module will
-execute on a failure. For example,
+=item 3
 
- onfail => sub { warn "CALL 911!" } 
+reference to the skipped test steps
+
+=item 4
+
+reference to the passed test steps
+
+=item 5
+
+reference to the failed test steps
 
 =back
 
+=head2 is_skip
+
+ $skip_on = is_skip( );
+ ($skip_on, $skip_diag) = is_skip( );
+
+Returns the object data set by the C<set_tests> subroutine.
+
 =head2 ok subroutine
 
  $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
@@ -736,10 +862,42 @@ that extends the &Test::skip the same as the
 L<ok subroutine|Test::Tech/ok> subroutine extends
 the I<&Test::ok> subroutine.
 
+=head2 plan subroutine
+
+ $success = plan(@args);
+
+The I<plan> subroutine is a cover method for &Test::plan.
+The I<@args> are passed unchanged to &Test::plan.
+All arguments are options. Valid options are as follows:
+
+=over 4
+
+=item tests
+
+The number of tests. For example
+
+ tests => 14,
+
+=item todo
+
+An array of test that will fail. For example
+
+ todo => [3,4]
+
+=item onfail
+
+A subroutine that the I<Test> module will
+execute on a failure. For example,
+
+ onfail => sub { warn "CALL 911!" } 
+
+=back
+
+
 =head2 skip_tests method
 
- $state = skip_tests( $on_off );
- $state = skip_tests( );
+ $skip_on = skip_tests( $on_off );
+ $skip_on = skip_tests( );
 
 The I<skip_tests> subroutine sets a flag that causes the
 I<ok> and the I<skip> methods to skip testing.
@@ -785,70 +943,6 @@ The variables for the top level 'Dumper' I<$dot_index> are
 established by "L<Data::Dumper|Data::Dumper>" module;
 for the top level 'Test', the "L<Test|Test>" module.
 
-=head2 finish subroutine
-
- (@stats) = $tech->finish( );
- $num_passed = $tech->finish( );
-
-The finish() subroutine/method outputs the test steps
-that are missing, failed, unplanned and other statistics.
-
-The finish() subroutine/method restores changes made
-to the 'Test' module module made by the 
-'tech_config' subroutine/method or directly.
-
-When the 'new' subroutine/method creates a 'Test::Tech'
-object, the Perl will automatically run the
-'finish' method when that object is destoried.
-
-Running the 'finish' method without a class or object,
-restores the 'Test' module to the values when
-the 'Test::Tech' module was loaded.
-
-The @stats array consists of the following:
-
-=over 4
-
-=item 0
-
-number of tests
-
-This is calculated as the maximum of the tests planned
-and the highest test number. From the maximum, substract
-the skipped tests. In other words, the sum of the missed,
-passed and failed test steps.
-
-=item 1
-
-reference to the unplanned test steps
-
-=item 2
-
-reference to the missed test steps
-
-=item 3
-
-reference to the skipped test steps
-
-=item 4
-
-reference to the passed test steps
-
-=item 5
-
-reference to the failed test steps
-
-=back
-
-=head2 demo subroutine
-
- demo($quoted_expression, @expression)
-
-The demo subroutine/method provides a session like out.
-The '$quoted_express' is printed out as typed in from
-the keyboard.
-The '@expression' is executed and printed out as the
-results of '$quoted_expression'.
 
 =head1 REQUIREMENTS
 
@@ -856,6 +950,10 @@ Coming soon.
 
 =head1 DEMONSTRATION
 
+ #########
+ # perl Tech.d
+ ###
+
  ~~~~~~ Demonstration overview ~~~~~
 
 Perl code begins with the prompt
@@ -891,11 +989,11 @@ follow on the next lines. For example,
  use warnings;
  use warnings::register;
  use vars qw($VERSION $DATE);
- $VERSION = '0.11';
- $DATE = '2004/04/08';
+ $VERSION = '0.13';
+ $DATE = '2004/04/15';
 
  BEGIN {
-    use FindBIN;
+    use FindBin;
     use File::Spec;
     use Cwd;
     use vars qw( $__restore_dir__ );
@@ -940,7 +1038,7 @@ follow on the next lines. For example,
        6, # expected results
        '','Skipped tests');
 
- #  zyw featureUnder development, i.e todo
+ #  zyw feature Under development, i.e todo
  ok( #  ok:  4
      $x*$y*2, # actual results
      6, # expected results
@@ -986,8 +1084,19 @@ follow on the next lines. For example,
 
  '
 
+ => ##################
+ => # Run test script techA0.t using Test 1.15
+ => # 
+ => ###
+
  =>     my $actual_results = `perl techA0.t`;
  =>     $snl->fout('tech1.txt', $actual_results);
+
+ => ##################
+ => # Run test script techA0.t using Test 1.15
+ => # 
+ => ###
+
  => $s->scrub_probe($s->scrub_file_line($actual_results))
  '1..8 todo 4 8;
  ok 1 - Test version 
@@ -999,12 +1108,8 @@ follow on the next lines. For example,
  not ok 5 - Failed test that skips the rest 
  # Test 5 got: '5' (xxxx.t at line 000)
  #   Expected: '6'
- ok 6 - A test to skip  # skip
- # Test 6 got:
- # Expected: (Test not performed because of previous failure.)
- ok 7 - A not skip to skip  # skip
- # Test 7 got:
- # Expected: (Test not performed because of previous failure.)
+ ok 6 - A test to skip  # skip - Test not performed because of previous failure.
+ ok 7 - A not skip to skip  # skip - Test not performed because of previous failure.
  ok 8 - Stop skipping tests. Todo Test that Passes  # (xxxx.t at line 000 TODO?!)
  ok 9 - Unplanned pass test 
  # Extra  : 9
@@ -1023,11 +1128,11 @@ follow on the next lines. For example,
  use warnings::register;
 
  use vars qw($VERSION $DATE);
- $VERSION = '0.12';
- $DATE = '2004/04/08';
+ $VERSION = '0.13';
+ $DATE = '2004/04/13';
 
  BEGIN {
-    use FindBIN;
+    use FindBin;
     use File::Spec;
     use Cwd;
     use vars qw( $__restore_dir__ );
@@ -1088,23 +1193,22 @@ follow on the next lines. For example,
 
  '
 
+ => ##################
+ => # Run test script techC0.t using Test 1.24
+ => # 
+ => ###
+
  =>     $actual_results = `perl techC0.t`;
  =>     $snl->fout('tech1.txt', $actual_results);
  => $s->scrub_probe($s->scrub_file_line($actual_results))
  '1..2 todo 1;
  ok 1 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
  not ok 2 - Test that fails 
- # Test 2 got: 'L[4]
-   A[0] 
-   A[5] ARRAY
-   A[1] 5
-   A[1] 6
+ # Test 2 got: 'U1[1] 80
+ U1[2] 5 6
  ' (xxxx.t at line 000)
- #   Expected: 'L[4]
-   A[0] 
-   A[5] ARRAY
-   A[1] 6
-   A[1] 5
+ #   Expected: 'U1[1] 80
+ U1[2] 6 5
  '
  # Failed : 2
  # Passed : 1/2 50%
@@ -1120,11 +1224,11 @@ follow on the next lines. For example,
  use warnings::register;
 
  use vars qw($VERSION $DATE);
- $VERSION = '0.07';
- $DATE = '2004/04/08';
+ $VERSION = '0.08';
+ $DATE = '2004/04/13';
 
  BEGIN {
-    use FindBIN;
+    use FindBin;
     use File::Spec;
     use Cwd;
     use vars qw( $__restore_dir__ );
@@ -1139,8 +1243,8 @@ follow on the next lines. For example,
     unshift @INC, File::Spec->catdir ( cwd(), 'V001024'); 
 
     require Test::Tech;
-    Test::Tech->import( qw(plan ok skip skip_tests tech_config finish) );
-    plan(tests => 8, todo => [4, 8]);
+    Test::Tech->import( qw(finish is_skip plan ok skip skip_tests tech_config ) );
+    plan(tests => 10, todo => [4, 8]);
  }
 
  END {
@@ -1184,11 +1288,23 @@ follow on the next lines. For example,
      [diagnostic => 'Should Turn on Skip Test', 
       name => 'Failed test that skips the rest']); 
 
+ my ($skip_on, $skip_diag) = is_skip();
+
  ok( #  ok:  6 
      $x + $y + $x, # actual results
      9, # expected results
      '', 'A test to skip');
 
+ ok( #  ok:  7 
+     skip_tests(0), # actual results
+     1, # expected results
+     '', 'Turn off skip');
+
+ ok( #  ok:  8 
+     [$skip_on, $skip_diag], # actual results
+     [1,'Skip test on'], # expected results
+     '', 'Skip flag');
+
  finish() # pick up stats
 
  __END__
@@ -1203,10 +1319,15 @@ follow on the next lines. For example,
 
  '
 
+ => ##################
+ => # Run test script techE0.t using Test 1.24
+ => # 
+ => ###
+
  =>     $actual_results = `perl techE0.t`;
  =>     $snl->fout('tech1.txt', $actual_results);
  => $s->scrub_probe($s->scrub_file_line($actual_results))
- '1..8 todo 4 8;
+ '1..10 todo 4 8;
  ok 1 - Test version 
  ok 2 - Pass test 
  ok 3 - Skipped tests  # skip
@@ -1216,36 +1337,103 @@ follow on the next lines. For example,
  not ok 5 - Failed test that skips the rest 
  # Test 5 got: '5' (xxxx.t at line 000)
  #   Expected: '6' (Should Turn on Skip Test)
- ok 6 - A test to skip  # skip
- # Test 6 got:
- # Expected: (Skip test on)
- # Missing: 7 8
+ ok 6 - A test to skip  # skip - Skip test on
+ ok 7 - Turn off skip 
+ ok 8 - Skip flag  # (xxxx.t at line 000 TODO?!)
+ not ok 9 Not Performed # missing 
+ # Test 9 got: (Missing)
+ # Expected: (Missing)
+ not ok 10 Not Performed # missing 
+ # Test 10 got: (Missing)
+ # Expected: (Missing)
+ # Missing: 9 10
  # Skipped: 3 6
- # Failed : 4 5
- # Passed : 2/6 33%
+ # Failed : 4 5 9 10
+ # Passed : 4/8 50%
  '
 
+ => ##################
+ => # config Test.ONFAIL, read undef
+ => # 
+ => ###
+
  => my $tech = new Test::Tech
- => $tech->tech_config('Test.TestLevel')
+ => $tech->tech_config('Test.ONFAIL')
  undef
 
- => $tech->tech_config('Test.TestLevel', 2)
+ => ##################
+ => # config Test.ONFAIL, read undef, write 0
+ => # 
+ => ###
+
+ => $tech->tech_config('Test.ONFAIL',0)
  undef
 
- => $tech->tech_config('Test.TestLevel')
- 2
+ => ##################
+ => # config Test.ONFAIL, read 0
+ => # 
+ => ###
 
- => $Test::TestLevel
- 2
+ => $tech->tech_config('Test.ONFAIL')
+ 0
 
- => $tech->finish( )
- => $Test::TestLevel
- undef
+ => ##################
+ => # $Test::ONFAIL, read 0
+ => # 
+ => ###
 
+ => $Test::ONFAIL
+ 0
+
+ => ##################
+ => # restore Test.ONFAIL on finish
+ => # 
+ => ###
+
+ =>      $tech->finish( );
+ =>      $Test::planned = 1;  # keep going
+
+ => ##################
+ => # Test.ONFAIL restored by finish()
+ => # 
+ => ###
+
+ => $tech->tech_config('Test.ONFAIL')
+ 0
+
+ => unlink 'tech1.txt'
  => unlink 'tech1.txt'
 
 =head1 QUALITY ASSURANCE
 
+=head2 Test Report
+
+ => perl Tech.t
+
+1..10
+# Running under perl version 5.006001 for MSWin32
+# Win32::BuildNumber 635
+# Current time local: Fri Apr 16 12:13:38 2004
+# Current time GMT:   Fri Apr 16 16:13:38 2004
+# Using Test.pm version 1.24
+# Test::Tech    : 1.20
+# Data::Secs2   : 1.17
+# Data::SecsPack: 0.02
+# =cut 
+ok 1 - UUT loaded 
+ok 2 - Run test script techA0.t using Test 1.15 
+ok 3 - Run test script techB0.t using Test 1.24 
+ok 4 - Run test script techC0.t using Test 1.24 
+ok 5 - Run test script techE0.t using Test 1.24 
+ok 6 - config Test.ONFAIL, read undef 
+ok 7 - config Test.ONFAIL, read undef, write 0 
+ok 8 - config Test.ONFAIL, read 0 
+ok 9 - 0, read 0 
+ok 10 - Test.ONFAIL restored by finish() 
+# Passed : 10/10 100%
+
+=head2 Test Script Notes
+
 Running the test script 'Tech.t' found in
 the "Test-Tech-$VERSION.tar.gz" distribution file verifies
 the requirements for this module.
